Top

    The Final Nights
    Westerville, Ohio
    January 27th 2008
    2R+F
    16 players
    Matt Piatek

    Deck Name:  Tembo!!
    Description: Demdemeh makes a herd of elephant allies with 2 hand
    damage and one bleed. Babalawo Alafin combines with Maabara to allow
    you to craft the hand you need.

    Crypt (13 cards, min=24, max=39, avg=8.15)
    ------------------------------------------
    3x Demdemeh	   10  ANI CEL FOR VIC aus pre	Tzimisce:4
    3x Matata	   9   ABO ANI FOR aus cel obf	Akunanse:3
    3x Babalawo Alafin 7   AUS FOR NEC ani		Harbinger of Skulls:4
    2x Wamukota	   9   ANI CHI FOR PRE aus	Ravnos:4
    2x Solomon Batanea 5   AUS FOR nec		Harbinger of Skulls:4

    Library (90)
    Master (14)
    3 Minion Tap
    2 Blood Doll
    2 Parthenon
    2 Maabara
    1 Lazarene Inquisitor
    1 Mbare Market, Harare
    1 Heidelburg Castle, Germany
    1 Crematorium
    1 Animalism

    Action (6)
    2 Rapid Healing
    2 Restoration
    1 Force of Will
    1 Tier of Souls

    Action modifier (7)
    5 Freak Drive
    2 Day Operations

    Reactions (17 cars)
    4 Wake with Evenigs Freshness
    2 Rat's Warning
    1 Guard Dog
    1 Cat's Guidance
    1 Eagle Sight
    2 Sprit Touch
    1 Precognition
    1 Enhanced Senses
    2 Telepathic Misderection
    1 My Enemy's Enemy
    1 Read the Winds

    Events(2)
    2 Anthelios, the Red Star

    Combat (27)
    6 Taste of Vitae
    4 Indomitability
    4 Rolling with the Punches
    3 Resilience
    2 Skin of Rock
    2 Unflinching Persistence
    2 Hidden Strength
    2 Drawing out the Beast
    1 Pack Alpha
    1 Canine Horde

    Retainers (14)
    7 Elephant Guardian
    3 Raven Spy
    2 Swarm
    1 J.S. Simmons
    1 Tasha Morgan

    Equipment (3)
    1 Erebus Mask
    1 Kerrie
    1 Unlicensed Taxicab

    Matt's comments on the final:

    It didn't work the way it was intended to in the finals. In retrospect
    I should have brought out Demdemeh instead of Wamukota as my second
    vampire, but I thought his ability would be important for my retain
    actions(it was never used). I never could get enough pool to bring
    out Demdemeh afterwards. A herd of elephants would have greatly
    increased my ousting ability.

    It is nice to know that the deck can survive without all of the "A"
    team in play.